/* global describe, it */

const expect = require('chai').expect;
const path = require('path');
const folderBased = require('../../src/generators/folder-based.js');

const simple = path.join(__dirname, '..', 'test-data', 'src');
const complex = path.join(__dirname, '..', 'test-data', 'src2');
const moreComplex = path.join(__dirname, '..', 'test-data', 'src3');
const params = path.join(__dirname, '..', 'test-data', 'src-params');

function verify(route, method, url) {
    expect(route.method).to.equal(method);
    expect(route.url).to.equal(url);
    expect(route.action).to.be.a('function');
}

describe('folder-based', function() {
    it('should generate correct routes for simple folder', function() {
        const routes = folderBased(simple);
        expect(routes).to.be.a('array');
        expect(routes.length).to.equal(1);
        verify(routes[0], 'all', '/home');
    });

    it('should generate correct routes for complex folder', function() {
        const routes = folderBased(complex);
        expect(routes).to.be.a('array');
        expect(routes.length).to.equal(4);
        verify(routes[0], 'all', '/');
        verify(routes[1], 'all', '/patient/assessment/create');
        verify(routes[2], 'all', '/patient/assessment');
        verify(routes[3], 'all', '/patient');
    });

    it('should generate correct routes for more complex folder', function() {
        const routes = folderBased(moreComplex);
        expect(routes).to.be.a('array');
        expect(routes.length).to.equal(3);
        verify(routes[0], 'get', '/');
        verify(routes[1], 'post', '/');
        verify(routes[2], 'all', '/simple');
    });

    it('should generate correct routes for more params folder', function() {
        const routes = folderBased(params);
        expect(routes).to.be.a('array');
        expect(routes.length).to.equal(3);
        verify(routes[0], 'get', '/patient/:id/details');
        verify(routes[1], 'post', '/patient/:id/details');
        verify(routes[2], 'all', '/patient/:id');
    });
});
